@@ -31,6 +31,12 @@ tensor_to_raw_vector <- function(x) {
   r
 }
 
+tensor_to_raw_vector_with_class <- function(x) {
+  r <- tensor_to_raw_vector(x)
+  class(r) <- "torch_serialized_tensor"
+  r
+}
+
 #' @concept serialization
 #' @export
 torch_save.nn_module <- function(obj, path, ...) {
@@ -39,32 +45,61 @@ torch_save.nn_module <- function(obj, path, ...) {
   saveRDS(list(module = obj, state_dict = state_raw, type = "module", version = 1), path)
 }
 
+#' @concept serialization
+#' @export
+torch_save.list <- function(obj, path, ...) {
+  
+  serialize_tensors <- function(x, f) {
+    lapply(x, function(x) {
+      if (is_torch_tensor(x)) {
+        tensor_to_raw_vector_with_class(x)
+      } else if (is.list(x)) {
+        serialize_tensors(x)
+      } else {
+        x
+      }
+    })
+  }
+  
+  serialized <- serialize_tensors(obj)
+  saveRDS(list(values = serialized, type = "list", version = 1), path)
+}
+
 #' Loads a saved object
 #'
 #' @param path a path to the saved object 
+#' @param device a device to load tensors to. By default we load to the `cpu` but you can also
+#'   load them to any `cuda` device. If `NULL` then the device where the tensor has been saved will
+#'   be reused.
 #' 
 #' @family torch_save
 #' 
 #' @export
 #' @concept serialization
-torch_load <- function(path) {
+torch_load <- function(path, device = "cpu") {
   r <- readRDS(path)
   if (r$type == "tensor")
-    torch_load_tensor(r)
+    torch_load_tensor(r, device)
   else if (r$type == "module")
-    torch_load_module(r)
+    torch_load_module(r, device)
+  else if (r$type == "list")
+    torch_load_list(r, device)
 }
 
-torch_load_tensor <- function(obj) {
-  Tensor$new(ptr = cpp_tensor_load(obj$values))
+torch_load_tensor <- function(obj, device = NULL) {
+  Tensor$new(ptr = cpp_tensor_load(obj$values, device))
 }
 
-torch_load_module <- function(obj) {
+load_tensor_from_raw <- function(x, device) {
+  con <- rawConnection(x)
+  r <- readRDS(con)
+  close(con)
+  torch_load_tensor(r, device)
+}
+
+torch_load_module <- function(obj, device = NULL) {
   obj$state_dict <- lapply(obj$state_dict, function(x) {
-    con <- rawConnection(x)
-    r <- readRDS(con)
-    close(con)
-    torch_load_tensor(r)
+    load_tensor_from_raw(x, device)
   })
   
   if (is.null(obj$version) || (obj$version < 1))
@@ -74,6 +109,20 @@ torch_load_module <- function(obj) {
   obj$module
 }
 
+torch_load_list <- function(obj, device = NULL) {
+  reload <- function(values) {
+    lapply(values, function(x) {
+      if (inherits(x, "torch_serialized_tensor"))
+        load_tensor_from_raw(x, device = device)
+      else if (is.list(x))
+        reload(x)
+      else 
+        x
+    })
+  }
+  reload(obj$values)
+}
+
 #' Load a state dict file
 #' 
 #' This function should only be used to load models saved in python.
