@@ -1,20 +1,20 @@
 #include "torch_types.h"
 #include <set>
 
-inline std::set<std::string> create_set(std::vector<std::string> v)
+inline std::set<std::string> create_set(const std::vector<std::string> v)
 {
-  std::set<std::string> s(v.begin(), v.end());
+  const std::set<std::string> s(v.begin(), v.end());
   return s;
 }
 
-inline bool is_in (std::string x, std::set<std::string> y)
+inline bool is_in (const std::string x, const std::set<std::string> y)
 {
   return y.find(x) != y.end();
 }
 
 // [[Rcpp::export]]
-std::string cpp_arg_to_torch_type (SEXP obj, std::vector<std::string> expected_types, 
-                                   std::string arg_name) 
+std::string cpp_arg_to_torch_type (SEXP obj, const std::vector<std::string> expected_types, 
+                                   const std::string arg_name) 
 {
 
   if (Rf_isSymbol(obj)) 
@@ -152,7 +152,8 @@ std::string cpp_arg_to_torch_type (SEXP obj, std::vector<std::string> expected_t
   Rcpp::stop("Can't convert argument");
 }
 
-inline std::string cpp_suffix (std::vector<std::string> arg_names, std::vector<std::string> arg_types)
+inline std::string cpp_suffix (const std::vector<std::string> arg_names, 
+                               const std::vector<std::string> arg_types)
 {
   std::string out;
   int arg_s = arg_names.size();
@@ -166,7 +167,7 @@ inline std::string cpp_suffix (std::vector<std::string> arg_names, std::vector<s
 }
 
 // [[Rcpp::export]]
-std::string cpp_clean_names (std::string x, std::vector<std::string> r)
+std::string cpp_clean_names (const std::string x, const std::vector<std::string> r)
 {
   std::string out = x;
   char replace;
@@ -179,13 +180,13 @@ std::string cpp_clean_names (std::string x, std::vector<std::string> r)
   return out;
 }
 
-std::vector<std::string> remove_characters = {"'", "\"", "%", "#", ":", ">", "<", ",", " ", "*", "&"};
+const std::vector<std::string> remove_characters = {"'", "\"", "%", "#", ":", ">", "<", ",", " ", "*", "&"};
 
 // [[Rcpp::export]]
-std::string cpp_make_function_name (std::string method_name, 
-                                    std::vector<std::string> arg_names, 
-                                    std::vector<std::string> arg_types,
-                                    std::string type)
+std::string cpp_make_function_name (const std::string method_name, 
+                                    const std::vector<std::string> arg_names, 
+                                    const std::vector<std::string> arg_types,
+                                    const std::string type)
 {
   std::string out = "cpp_torch_" + type + "_" + method_name + "_";
   out += cpp_suffix(arg_names, arg_types);
@@ -194,9 +195,9 @@ std::string cpp_make_function_name (std::string method_name,
 }
 
 // [[Rcpp::export]]
-std::string create_fn_name (std::string fun_name, std::string fun_type, 
-                            std::vector<std::string> nd_args, Rcpp::List args, 
-                            Rcpp::List expected_types)
+std::string create_fn_name (const std::string fun_name, const std::string fun_type, 
+                            const std::vector<std::string> nd_args, const Rcpp::List args, 
+                            const Rcpp::List expected_types)
 {
   std::vector<std::string> arg_names;
   std::vector<std::string> arg_types;
@@ -212,7 +213,7 @@ std::string create_fn_name (std::string fun_name, std::string fun_type,
     }
   }
   
-  auto nm = cpp_make_function_name(fun_name, arg_names, arg_types, fun_type);
+  const auto nm = cpp_make_function_name(fun_name, arg_names, arg_types, fun_type);
   
   return nm;
 }
