@@ -24,7 +24,7 @@ Rcpp::List cpp_variable_list_to_r_list(Rcpp::XPtr<XPtrTorchvariable_list> x)
   for (int64_t i = 0; i < sze; i++)
   {
     void * tmp = lantern_variable_list_get(x->get(), i);
-    out.push_back(make_xptr<XPtrTorchTensor>(tmp));
+    out.push_back(XPtrTorchTensor(tmp));
   }
 
   return out;
